# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.member_update_parameters import MemberUpdateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestMemberUpdateParameters(unittest.TestCase):
    """MemberUpdateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MemberUpdateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.member_update_parameters.MemberUpdateParameters()  # noqa: E501
        if include_optional :
            return MemberUpdateParameters(
                strategy = 'set', 
                role = 'Developer', 
                project_ids = 'abcd1234abcd1234abcd1234,abcd1234abcd1234abcd1235', 
                locale_ids = 'abcd1234abcd1234abcd1234,abcd1234abcd1234abcd1235', 
                default_locale_codes = ["en","fi"], 
                space_ids = ["abcd1234abcd1234abcd1234","abcd1234abcd1234abcd1235"], 
                permissions = {"create_upload":true,"review_translations":true}
            )
        else :
            return MemberUpdateParameters(
        )

    def testMemberUpdateParameters(self):
        """Test MemberUpdateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.job_update_parameters import JobUpdateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestJobUpdateParameters(unittest.TestCase):
    """JobUpdateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test JobUpdateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.job_update_parameters.JobUpdateParameters()  # noqa: E501
        if include_optional :
            return JobUpdateParameters(
                branch = 'my-feature-branch', 
                name = 'de', 
                briefing = 'de-DE', 
                due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                ticket_url = 'https://example.atlassian.net/browse/FOO'
            )
        else :
            return JobUpdateParameters(
        )

    def testJobUpdateParameters(self):
        """Test JobUpdateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.distribution_update_parameters import DistributionUpdateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestDistributionUpdateParameters(unittest.TestCase):
    """DistributionUpdateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DistributionUpdateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.distribution_update_parameters.DistributionUpdateParameters()  # noqa: E501
        if include_optional :
            return DistributionUpdateParameters(
                name = 'My Android Distribution', 
                project_id = 'abcd1234abcd1234abcd1234', 
                platforms = ["android","ios"], 
                locale_ids = ["abcd1234cdef1234abcd1234cdef1234","fff565db236400772368235db2c6117e"], 
                format_options = {xml:{enclose_in_cdata:'1'}}, 
                fallback_locales_enabled = True, 
                fallback_to_non_regional_locale = True, 
                fallback_to_default_locale = True, 
                use_last_reviewed_version = True
            )
        else :
            return DistributionUpdateParameters(
        )

    def testDistributionUpdateParameters(self):
        """Test DistributionUpdateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.teams_api import TeamsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestTeamsApi(unittest.TestCase):
    """TeamsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.teams_api.TeamsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_team_create(self):
        """Test case for team_create

        Create a Team  # noqa: E501
        """
        pass

    def test_team_delete(self):
        """Test case for team_delete

        Delete Team  # noqa: E501
        """
        pass

    def test_team_show(self):
        """Test case for team_show

        Get Team  # noqa: E501
        """
        pass

    def test_team_update(self):
        """Test case for team_update

        Update Team  # noqa: E501
        """
        pass

    def test_teams_list(self):
        """Test case for teams_list

        List Teams  # noqa: E501
        """
        pass

    def test_teams_projects_create(self):
        """Test case for teams_projects_create

        Add Project  # noqa: E501
        """
        pass

    def test_teams_projects_delete(self):
        """Test case for teams_projects_delete

        Remove Project  # noqa: E501
        """
        pass

    def test_teams_spaces_create(self):
        """Test case for teams_spaces_create

        Add Space  # noqa: E501
        """
        pass

    def test_teams_spaces_delete(self):
        """Test case for teams_spaces_delete

        Remove Space  # noqa: E501
        """
        pass

    def test_teams_users_create(self):
        """Test case for teams_users_create

        Add User  # noqa: E501
        """
        pass

    def test_teams_users_delete(self):
        """Test case for teams_users_delete

        Remove User  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class Notification(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'event_name': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'delivered_at': 'datetime',
        'seen_at': 'datetime',
        'data': 'object',
        'resource': 'object',
        'locale': 'Locale',
        'user': 'UserPreview',
        'project': 'Project',
        'account': 'Account',
        'group': 'NotificationGroup'
    }

    attribute_map = {
        'id': 'id',
        'event_name': 'event_name',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'delivered_at': 'delivered_at',
        'seen_at': 'seen_at',
        'data': 'data',
        'resource': 'resource',
        'locale': 'locale',
        'user': 'user',
        'project': 'project',
        'account': 'account',
        'group': 'group'
    }

    def __init__(self, id=None, event_name=None, created_at=None, updated_at=None, delivered_at=None, seen_at=None, data=None, resource=None, locale=None, user=None, project=None, account=None, group=None, local_vars_configuration=None):  # noqa: E501
        """Notification - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._event_name = None
        self._created_at = None
        self._updated_at = None
        self._delivered_at = None
        self._seen_at = None
        self._data = None
        self._resource = None
        self._locale = None
        self._user = None
        self._project = None
        self._account = None
        self._group = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if event_name is not None:
            self.event_name = event_name
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if delivered_at is not None:
            self.delivered_at = delivered_at
        if seen_at is not None:
            self.seen_at = seen_at
        if data is not None:
            self.data = data
        if resource is not None:
            self.resource = resource
        if locale is not None:
            self.locale = locale
        if user is not None:
            self.user = user
        if project is not None:
            self.project = project
        if account is not None:
            self.account = account
        if group is not None:
            self.group = group

    @property
    def id(self):
        """Gets the id of this Notification.  # noqa: E501


        :return: The id of this Notification.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Notification.


        :param id: The id of this Notification.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def event_name(self):
        """Gets the event_name of this Notification.  # noqa: E501


        :return: The event_name of this Notification.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this Notification.


        :param event_name: The event_name of this Notification.  # noqa: E501
        :type: str
        """

        self._event_name = event_name

    @property
    def created_at(self):
        """Gets the created_at of this Notification.  # noqa: E501


        :return: The created_at of this Notification.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Notification.


        :param created_at: The created_at of this Notification.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Notification.  # noqa: E501


        :return: The updated_at of this Notification.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Notification.


        :param updated_at: The updated_at of this Notification.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def delivered_at(self):
        """Gets the delivered_at of this Notification.  # noqa: E501


        :return: The delivered_at of this Notification.  # noqa: E501
        :rtype: datetime
        """
        return self._delivered_at

    @delivered_at.setter
    def delivered_at(self, delivered_at):
        """Sets the delivered_at of this Notification.


        :param delivered_at: The delivered_at of this Notification.  # noqa: E501
        :type: datetime
        """

        self._delivered_at = delivered_at

    @property
    def seen_at(self):
        """Gets the seen_at of this Notification.  # noqa: E501


        :return: The seen_at of this Notification.  # noqa: E501
        :rtype: datetime
        """
        return self._seen_at

    @seen_at.setter
    def seen_at(self, seen_at):
        """Sets the seen_at of this Notification.


        :param seen_at: The seen_at of this Notification.  # noqa: E501
        :type: datetime
        """

        self._seen_at = seen_at

    @property
    def data(self):
        """Gets the data of this Notification.  # noqa: E501


        :return: The data of this Notification.  # noqa: E501
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this Notification.


        :param data: The data of this Notification.  # noqa: E501
        :type: object
        """

        self._data = data

    @property
    def resource(self):
        """Gets the resource of this Notification.  # noqa: E501


        :return: The resource of this Notification.  # noqa: E501
        :rtype: object
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this Notification.


        :param resource: The resource of this Notification.  # noqa: E501
        :type: object
        """

        self._resource = resource

    @property
    def locale(self):
        """Gets the locale of this Notification.  # noqa: E501


        :return: The locale of this Notification.  # noqa: E501
        :rtype: Locale
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this Notification.


        :param locale: The locale of this Notification.  # noqa: E501
        :type: Locale
        """

        self._locale = locale

    @property
    def user(self):
        """Gets the user of this Notification.  # noqa: E501


        :return: The user of this Notification.  # noqa: E501
        :rtype: UserPreview
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Notification.


        :param user: The user of this Notification.  # noqa: E501
        :type: UserPreview
        """

        self._user = user

    @property
    def project(self):
        """Gets the project of this Notification.  # noqa: E501


        :return: The project of this Notification.  # noqa: E501
        :rtype: Project
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this Notification.


        :param project: The project of this Notification.  # noqa: E501
        :type: Project
        """

        self._project = project

    @property
    def account(self):
        """Gets the account of this Notification.  # noqa: E501


        :return: The account of this Notification.  # noqa: E501
        :rtype: Account
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Notification.


        :param account: The account of this Notification.  # noqa: E501
        :type: Account
        """

        self._account = account

    @property
    def group(self):
        """Gets the group of this Notification.  # noqa: E501


        :return: The group of this Notification.  # noqa: E501
        :rtype: NotificationGroup
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this Notification.


        :param group: The group of this Notification.  # noqa: E501
        :type: NotificationGroup
        """

        self._group = group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Notification):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Notification):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.translation_version import TranslationVersion  # noqa: E501
from phrase_api.rest import ApiException

class TestTranslationVersion(unittest.TestCase):
    """TranslationVersion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TranslationVersion
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.translation_version.TranslationVersion()  # noqa: E501
        if include_optional :
            return TranslationVersion(
                id = '0', 
                content = '0', 
                plural_suffix = '0', 
                key = phrase_api.models.key_preview.key_preview(
                    id = '0', 
                    name = '0', 
                    plural = True, ), 
                locale = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"English","code":"en-GB"}, 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                changed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else :
            return TranslationVersion(
        )

    def testTranslationVersion(self):
        """Test TranslationVersion"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.jobs_api import JobsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.jobs_api.JobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_job_complete(self):
        """Test case for job_complete

        Complete a job  # noqa: E501
        """
        pass

    def test_job_create(self):
        """Test case for job_create

        Create a job  # noqa: E501
        """
        pass

    def test_job_delete(self):
        """Test case for job_delete

        Delete a job  # noqa: E501
        """
        pass

    def test_job_keys_create(self):
        """Test case for job_keys_create

        Add keys to job  # noqa: E501
        """
        pass

    def test_job_keys_delete(self):
        """Test case for job_keys_delete

        Remove keys from job  # noqa: E501
        """
        pass

    def test_job_lock(self):
        """Test case for job_lock

        Lock a job  # noqa: E501
        """
        pass

    def test_job_reopen(self):
        """Test case for job_reopen

        Reopen a job  # noqa: E501
        """
        pass

    def test_job_show(self):
        """Test case for job_show

        Get a single job  # noqa: E501
        """
        pass

    def test_job_start(self):
        """Test case for job_start

        Start a job  # noqa: E501
        """
        pass

    def test_job_unlock(self):
        """Test case for job_unlock

        Unlock a job  # noqa: E501
        """
        pass

    def test_job_update(self):
        """Test case for job_update

        Update a job  # noqa: E501
        """
        pass

    def test_jobs_by_account(self):
        """Test case for jobs_by_account

        List account jobs  # noqa: E501
        """
        pass

    def test_jobs_list(self):
        """Test case for jobs_list

        List jobs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.orders_api import OrdersApi  # noqa: E501
from phrase_api.rest import ApiException


class TestOrdersApi(unittest.TestCase):
    """OrdersApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.orders_api.OrdersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_order_confirm(self):
        """Test case for order_confirm

        Confirm an order  # noqa: E501
        """
        pass

    def test_order_create(self):
        """Test case for order_create

        Create a new order  # noqa: E501
        """
        pass

    def test_order_delete(self):
        """Test case for order_delete

        Cancel an order  # noqa: E501
        """
        pass

    def test_order_show(self):
        """Test case for order_show

        Get a single order  # noqa: E501
        """
        pass

    def test_orders_list(self):
        """Test case for orders_list

        List orders  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.releases_api import ReleasesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestReleasesApi(unittest.TestCase):
    """ReleasesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.releases_api.ReleasesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_release_create(self):
        """Test case for release_create

        Create a release  # noqa: E501
        """
        pass

    def test_release_delete(self):
        """Test case for release_delete

        Delete a release  # noqa: E501
        """
        pass

    def test_release_publish(self):
        """Test case for release_publish

        Publish a release  # noqa: E501
        """
        pass

    def test_release_show(self):
        """Test case for release_show

        Get a single release  # noqa: E501
        """
        pass

    def test_release_update(self):
        """Test case for release_update

        Update a release  # noqa: E501
        """
        pass

    def test_releases_list(self):
        """Test case for releases_list

        List releases  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.glossary_terms_api import GlossaryTermsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestGlossaryTermsApi(unittest.TestCase):
    """GlossaryTermsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.glossary_terms_api.GlossaryTermsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_glossary_term_create(self):
        """Test case for glossary_term_create

        Create a term  # noqa: E501
        """
        pass

    def test_glossary_term_delete(self):
        """Test case for glossary_term_delete

        Delete a term  # noqa: E501
        """
        pass

    def test_glossary_term_show(self):
        """Test case for glossary_term_show

        Get a single term  # noqa: E501
        """
        pass

    def test_glossary_term_update(self):
        """Test case for glossary_term_update

        Update a term  # noqa: E501
        """
        pass

    def test_glossary_terms_list(self):
        """Test case for glossary_terms_list

        List terms  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class Invitation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'email': 'str',
        'role': 'str',
        'state': 'str',
        'projects': 'list[ProjectShort]',
        'locales': 'list[LocalePreview]',
        'teams': 'list[TeamShort]',
        'default_locale_codes': 'list[str]',
        'permissions': 'object',
        'locale_ids': 'list[str]',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'accepted_at': 'datetime',
        'spaces': 'list[Space]',
        'project_role': 'list[MemberProjectDetailProjectRoles]'
    }

    attribute_map = {
        'id': 'id',
        'email': 'email',
        'role': 'role',
        'state': 'state',
        'projects': 'projects',
        'locales': 'locales',
        'teams': 'teams',
        'default_locale_codes': 'default_locale_codes',
        'permissions': 'permissions',
        'locale_ids': 'locale_ids',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'accepted_at': 'accepted_at',
        'spaces': 'spaces',
        'project_role': 'project_role'
    }

    def __init__(self, id=None, email=None, role=None, state=None, projects=None, locales=None, teams=None, default_locale_codes=None, permissions=None, locale_ids=None, created_at=None, updated_at=None, accepted_at=None, spaces=None, project_role=None, local_vars_configuration=None):  # noqa: E501
        """Invitation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._email = None
        self._role = None
        self._state = None
        self._projects = None
        self._locales = None
        self._teams = None
        self._default_locale_codes = None
        self._permissions = None
        self._locale_ids = None
        self._created_at = None
        self._updated_at = None
        self._accepted_at = None
        self._spaces = None
        self._project_role = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if email is not None:
            self.email = email
        if role is not None:
            self.role = role
        if state is not None:
            self.state = state
        if projects is not None:
            self.projects = projects
        if locales is not None:
            self.locales = locales
        if teams is not None:
            self.teams = teams
        if default_locale_codes is not None:
            self.default_locale_codes = default_locale_codes
        if permissions is not None:
            self.permissions = permissions
        if locale_ids is not None:
            self.locale_ids = locale_ids
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if accepted_at is not None:
            self.accepted_at = accepted_at
        if spaces is not None:
            self.spaces = spaces
        if project_role is not None:
            self.project_role = project_role

    @property
    def id(self):
        """Gets the id of this Invitation.  # noqa: E501


        :return: The id of this Invitation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Invitation.


        :param id: The id of this Invitation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def email(self):
        """Gets the email of this Invitation.  # noqa: E501


        :return: The email of this Invitation.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Invitation.


        :param email: The email of this Invitation.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def role(self):
        """Gets the role of this Invitation.  # noqa: E501


        :return: The role of this Invitation.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this Invitation.


        :param role: The role of this Invitation.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def state(self):
        """Gets the state of this Invitation.  # noqa: E501


        :return: The state of this Invitation.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Invitation.


        :param state: The state of this Invitation.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def projects(self):
        """Gets the projects of this Invitation.  # noqa: E501


        :return: The projects of this Invitation.  # noqa: E501
        :rtype: list[ProjectShort]
        """
        return self._projects

    @projects.setter
    def projects(self, projects):
        """Sets the projects of this Invitation.


        :param projects: The projects of this Invitation.  # noqa: E501
        :type: list[ProjectShort]
        """

        self._projects = projects

    @property
    def locales(self):
        """Gets the locales of this Invitation.  # noqa: E501


        :return: The locales of this Invitation.  # noqa: E501
        :rtype: list[LocalePreview]
        """
        return self._locales

    @locales.setter
    def locales(self, locales):
        """Sets the locales of this Invitation.


        :param locales: The locales of this Invitation.  # noqa: E501
        :type: list[LocalePreview]
        """

        self._locales = locales

    @property
    def teams(self):
        """Gets the teams of this Invitation.  # noqa: E501


        :return: The teams of this Invitation.  # noqa: E501
        :rtype: list[TeamShort]
        """
        return self._teams

    @teams.setter
    def teams(self, teams):
        """Sets the teams of this Invitation.


        :param teams: The teams of this Invitation.  # noqa: E501
        :type: list[TeamShort]
        """

        self._teams = teams

    @property
    def default_locale_codes(self):
        """Gets the default_locale_codes of this Invitation.  # noqa: E501


        :return: The default_locale_codes of this Invitation.  # noqa: E501
        :rtype: list[str]
        """
        return self._default_locale_codes

    @default_locale_codes.setter
    def default_locale_codes(self, default_locale_codes):
        """Sets the default_locale_codes of this Invitation.


        :param default_locale_codes: The default_locale_codes of this Invitation.  # noqa: E501
        :type: list[str]
        """

        self._default_locale_codes = default_locale_codes

    @property
    def permissions(self):
        """Gets the permissions of this Invitation.  # noqa: E501


        :return: The permissions of this Invitation.  # noqa: E501
        :rtype: object
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this Invitation.


        :param permissions: The permissions of this Invitation.  # noqa: E501
        :type: object
        """

        self._permissions = permissions

    @property
    def locale_ids(self):
        """Gets the locale_ids of this Invitation.  # noqa: E501


        :return: The locale_ids of this Invitation.  # noqa: E501
        :rtype: list[str]
        """
        return self._locale_ids

    @locale_ids.setter
    def locale_ids(self, locale_ids):
        """Sets the locale_ids of this Invitation.


        :param locale_ids: The locale_ids of this Invitation.  # noqa: E501
        :type: list[str]
        """

        self._locale_ids = locale_ids

    @property
    def created_at(self):
        """Gets the created_at of this Invitation.  # noqa: E501


        :return: The created_at of this Invitation.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Invitation.


        :param created_at: The created_at of this Invitation.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Invitation.  # noqa: E501


        :return: The updated_at of this Invitation.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Invitation.


        :param updated_at: The updated_at of this Invitation.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def accepted_at(self):
        """Gets the accepted_at of this Invitation.  # noqa: E501


        :return: The accepted_at of this Invitation.  # noqa: E501
        :rtype: datetime
        """
        return self._accepted_at

    @accepted_at.setter
    def accepted_at(self, accepted_at):
        """Sets the accepted_at of this Invitation.


        :param accepted_at: The accepted_at of this Invitation.  # noqa: E501
        :type: datetime
        """

        self._accepted_at = accepted_at

    @property
    def spaces(self):
        """Gets the spaces of this Invitation.  # noqa: E501


        :return: The spaces of this Invitation.  # noqa: E501
        :rtype: list[Space]
        """
        return self._spaces

    @spaces.setter
    def spaces(self, spaces):
        """Sets the spaces of this Invitation.


        :param spaces: The spaces of this Invitation.  # noqa: E501
        :type: list[Space]
        """

        self._spaces = spaces

    @property
    def project_role(self):
        """Gets the project_role of this Invitation.  # noqa: E501


        :return: The project_role of this Invitation.  # noqa: E501
        :rtype: list[MemberProjectDetailProjectRoles]
        """
        return self._project_role

    @project_role.setter
    def project_role(self, project_role):
        """Sets the project_role of this Invitation.


        :param project_role: The project_role of this Invitation.  # noqa: E501
        :type: list[MemberProjectDetailProjectRoles]
        """

        self._project_role = project_role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Invitation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Invitation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class DistributionCreateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'project_id': 'str',
        'platforms': 'list[str]',
        'locale_ids': 'list[str]',
        'format_options': 'dict(str, str)',
        'fallback_locales_enabled': 'bool',
        'fallback_to_non_regional_locale': 'bool',
        'fallback_to_default_locale': 'bool',
        'use_last_reviewed_version': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'project_id': 'project_id',
        'platforms': 'platforms',
        'locale_ids': 'locale_ids',
        'format_options': 'format_options',
        'fallback_locales_enabled': 'fallback_locales_enabled',
        'fallback_to_non_regional_locale': 'fallback_to_non_regional_locale',
        'fallback_to_default_locale': 'fallback_to_default_locale',
        'use_last_reviewed_version': 'use_last_reviewed_version'
    }

    def __init__(self, name=None, project_id=None, platforms=None, locale_ids=None, format_options=None, fallback_locales_enabled=None, fallback_to_non_regional_locale=None, fallback_to_default_locale=None, use_last_reviewed_version=None, local_vars_configuration=None):  # noqa: E501
        """DistributionCreateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._project_id = None
        self._platforms = None
        self._locale_ids = None
        self._format_options = None
        self._fallback_locales_enabled = None
        self._fallback_to_non_regional_locale = None
        self._fallback_to_default_locale = None
        self._use_last_reviewed_version = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if project_id is not None:
            self.project_id = project_id
        if platforms is not None:
            self.platforms = platforms
        if locale_ids is not None:
            self.locale_ids = locale_ids
        if format_options is not None:
            self.format_options = format_options
        if fallback_locales_enabled is not None:
            self.fallback_locales_enabled = fallback_locales_enabled
        if fallback_to_non_regional_locale is not None:
            self.fallback_to_non_regional_locale = fallback_to_non_regional_locale
        if fallback_to_default_locale is not None:
            self.fallback_to_default_locale = fallback_to_default_locale
        if use_last_reviewed_version is not None:
            self.use_last_reviewed_version = use_last_reviewed_version

    @property
    def name(self):
        """Gets the name of this DistributionCreateParameters.  # noqa: E501

        Name of the distribution  # noqa: E501

        :return: The name of this DistributionCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DistributionCreateParameters.

        Name of the distribution  # noqa: E501

        :param name: The name of this DistributionCreateParameters.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this DistributionCreateParameters.  # noqa: E501

        Project id the distribution should be assigned to.  # noqa: E501

        :return: The project_id of this DistributionCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this DistributionCreateParameters.

        Project id the distribution should be assigned to.  # noqa: E501

        :param project_id: The project_id of this DistributionCreateParameters.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def platforms(self):
        """Gets the platforms of this DistributionCreateParameters.  # noqa: E501

        List of platforms the distribution should support.  # noqa: E501

        :return: The platforms of this DistributionCreateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._platforms

    @platforms.setter
    def platforms(self, platforms):
        """Sets the platforms of this DistributionCreateParameters.

        List of platforms the distribution should support.  # noqa: E501

        :param platforms: The platforms of this DistributionCreateParameters.  # noqa: E501
        :type: list[str]
        """

        self._platforms = platforms

    @property
    def locale_ids(self):
        """Gets the locale_ids of this DistributionCreateParameters.  # noqa: E501

        List of locale ids that will be part of distribution releases  # noqa: E501

        :return: The locale_ids of this DistributionCreateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._locale_ids

    @locale_ids.setter
    def locale_ids(self, locale_ids):
        """Sets the locale_ids of this DistributionCreateParameters.

        List of locale ids that will be part of distribution releases  # noqa: E501

        :param locale_ids: The locale_ids of this DistributionCreateParameters.  # noqa: E501
        :type: list[str]
        """

        self._locale_ids = locale_ids

    @property
    def format_options(self):
        """Gets the format_options of this DistributionCreateParameters.  # noqa: E501

        Additional formatting and render options. Only <code>enclose_in_cdata</code> is available for platform <code>android</code>.  # noqa: E501

        :return: The format_options of this DistributionCreateParameters.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._format_options

    @format_options.setter
    def format_options(self, format_options):
        """Sets the format_options of this DistributionCreateParameters.

        Additional formatting and render options. Only <code>enclose_in_cdata</code> is available for platform <code>android</code>.  # noqa: E501

        :param format_options: The format_options of this DistributionCreateParameters.  # noqa: E501
        :type: dict(str, str)
        """

        self._format_options = format_options

    @property
    def fallback_locales_enabled(self):
        """Gets the fallback_locales_enabled of this DistributionCreateParameters.  # noqa: E501

        Use fallback locale if there is no translation in the current locale.  # noqa: E501

        :return: The fallback_locales_enabled of this DistributionCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._fallback_locales_enabled

    @fallback_locales_enabled.setter
    def fallback_locales_enabled(self, fallback_locales_enabled):
        """Sets the fallback_locales_enabled of this DistributionCreateParameters.

        Use fallback locale if there is no translation in the current locale.  # noqa: E501

        :param fallback_locales_enabled: The fallback_locales_enabled of this DistributionCreateParameters.  # noqa: E501
        :type: bool
        """

        self._fallback_locales_enabled = fallback_locales_enabled

    @property
    def fallback_to_non_regional_locale(self):
        """Gets the fallback_to_non_regional_locale of this DistributionCreateParameters.  # noqa: E501

        Indicates whether to fallback to non regional locale when locale can not be found  # noqa: E501

        :return: The fallback_to_non_regional_locale of this DistributionCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._fallback_to_non_regional_locale

    @fallback_to_non_regional_locale.setter
    def fallback_to_non_regional_locale(self, fallback_to_non_regional_locale):
        """Sets the fallback_to_non_regional_locale of this DistributionCreateParameters.

        Indicates whether to fallback to non regional locale when locale can not be found  # noqa: E501

        :param fallback_to_non_regional_locale: The fallback_to_non_regional_locale of this DistributionCreateParameters.  # noqa: E501
        :type: bool
        """

        self._fallback_to_non_regional_locale = fallback_to_non_regional_locale

    @property
    def fallback_to_default_locale(self):
        """Gets the fallback_to_default_locale of this DistributionCreateParameters.  # noqa: E501

        Indicates whether to fallback to projects default locale when locale can not be found  # noqa: E501

        :return: The fallback_to_default_locale of this DistributionCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._fallback_to_default_locale

    @fallback_to_default_locale.setter
    def fallback_to_default_locale(self, fallback_to_default_locale):
        """Sets the fallback_to_default_locale of this DistributionCreateParameters.

        Indicates whether to fallback to projects default locale when locale can not be found  # noqa: E501

        :param fallback_to_default_locale: The fallback_to_default_locale of this DistributionCreateParameters.  # noqa: E501
        :type: bool
        """

        self._fallback_to_default_locale = fallback_to_default_locale

    @property
    def use_last_reviewed_version(self):
        """Gets the use_last_reviewed_version of this DistributionCreateParameters.  # noqa: E501

        Use last reviewed instead of latest translation in a project  # noqa: E501

        :return: The use_last_reviewed_version of this DistributionCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._use_last_reviewed_version

    @use_last_reviewed_version.setter
    def use_last_reviewed_version(self, use_last_reviewed_version):
        """Sets the use_last_reviewed_version of this DistributionCreateParameters.

        Use last reviewed instead of latest translation in a project  # noqa: E501

        :param use_last_reviewed_version: The use_last_reviewed_version of this DistributionCreateParameters.  # noqa: E501
        :type: bool
        """

        self._use_last_reviewed_version = use_last_reviewed_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DistributionCreateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DistributionCreateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class KeysExcludeParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'q': 'str',
        'target_locale_id': 'str',
        'tags': 'str'
    }

    attribute_map = {
        'branch': 'branch',
        'q': 'q',
        'target_locale_id': 'target_locale_id',
        'tags': 'tags'
    }

    def __init__(self, branch=None, q=None, target_locale_id=None, tags=None, local_vars_configuration=None):  # noqa: E501
        """KeysExcludeParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._q = None
        self._target_locale_id = None
        self._tags = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if q is not None:
            self.q = q
        if target_locale_id is not None:
            self.target_locale_id = target_locale_id
        if tags is not None:
            self.tags = tags

    @property
    def branch(self):
        """Gets the branch of this KeysExcludeParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this KeysExcludeParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this KeysExcludeParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this KeysExcludeParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def q(self):
        """Gets the q of this KeysExcludeParameters.  # noqa: E501

        Specify a query to do broad search for keys by name (including wildcards).<br><br> The following qualifiers are also supported in the search term:<br> <ul>   <li><code>ids:key_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>name:key_name</code> for text queries on exact key names - spaces, commas, and colons  need to be escaped with double backslashes</li>   <li><code>tags:tag_name</code> to filter for keys with certain tags</li>   <li><code>translated:{true|false}</code> for translation status (also requires <code>locale_id</code> to be specified)</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li>   <li><code>unmentioned_in_upload:upload_id</code> to filter keys unmentioned within upload</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>.   # noqa: E501

        :return: The q of this KeysExcludeParameters.  # noqa: E501
        :rtype: str
        """
        return self._q

    @q.setter
    def q(self, q):
        """Sets the q of this KeysExcludeParameters.

        Specify a query to do broad search for keys by name (including wildcards).<br><br> The following qualifiers are also supported in the search term:<br> <ul>   <li><code>ids:key_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>name:key_name</code> for text queries on exact key names - spaces, commas, and colons  need to be escaped with double backslashes</li>   <li><code>tags:tag_name</code> to filter for keys with certain tags</li>   <li><code>translated:{true|false}</code> for translation status (also requires <code>locale_id</code> to be specified)</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li>   <li><code>unmentioned_in_upload:upload_id</code> to filter keys unmentioned within upload</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>.   # noqa: E501

        :param q: The q of this KeysExcludeParameters.  # noqa: E501
        :type: str
        """

        self._q = q

    @property
    def target_locale_id(self):
        """Gets the target_locale_id of this KeysExcludeParameters.  # noqa: E501

        Locale used to exlcude or include keys.  # noqa: E501

        :return: The target_locale_id of this KeysExcludeParameters.  # noqa: E501
        :rtype: str
        """
        return self._target_locale_id

    @target_locale_id.setter
    def target_locale_id(self, target_locale_id):
        """Sets the target_locale_id of this KeysExcludeParameters.

        Locale used to exlcude or include keys.  # noqa: E501

        :param target_locale_id: The target_locale_id of this KeysExcludeParameters.  # noqa: E501
        :type: str
        """

        self._target_locale_id = target_locale_id

    @property
    def tags(self):
        """Gets the tags of this KeysExcludeParameters.  # noqa: E501

        Tag or comma-separated list of tags to add to the matching collection of keys  # noqa: E501

        :return: The tags of this KeysExcludeParameters.  # noqa: E501
        :rtype: str
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this KeysExcludeParameters.

        Tag or comma-separated list of tags to add to the matching collection of keys  # noqa: E501

        :param tags: The tags of this KeysExcludeParameters.  # noqa: E501
        :type: str
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeysExcludeParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KeysExcludeParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.webhooks_api import WebhooksApi  # noqa: E501
from phrase_api.rest import ApiException


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.webhooks_api.WebhooksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_webhook_create(self):
        """Test case for webhook_create

        Create a webhook  # noqa: E501
        """
        pass

    def test_webhook_delete(self):
        """Test case for webhook_delete

        Delete a webhook  # noqa: E501
        """
        pass

    def test_webhook_show(self):
        """Test case for webhook_show

        Get a single webhook  # noqa: E501
        """
        pass

    def test_webhook_test(self):
        """Test case for webhook_test

        Test a webhook  # noqa: E501
        """
        pass

    def test_webhook_update(self):
        """Test case for webhook_update

        Update a webhook  # noqa: E501
        """
        pass

    def test_webhooks_list(self):
        """Test case for webhooks_list

        List webhooks  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.translation_order import TranslationOrder  # noqa: E501
from phrase_api.rest import ApiException

class TestTranslationOrder(unittest.TestCase):
    """TranslationOrder unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TranslationOrder
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.translation_order.TranslationOrder()  # noqa: E501
        if include_optional :
            return TranslationOrder(
                id = '0', 
                name = '0', 
                lsp = '0', 
                amount_in_cents = 56, 
                currency = '0', 
                message = '0', 
                state = '0', 
                translation_type = '0', 
                progress_percent = 56, 
                source_locale = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"English","code":"en-GB"}, 
                target_locales = [
                    {"id":"abcd1234cdef1234abcd1234cdef1234","name":"English","code":"en-GB"}
                    ], 
                tag = '0', 
                styleguide = {"id":"abcd1234cdef1234abcd1234cdef1234","title":"My Style Guide"}, 
                unverify_translations_upon_delivery = True, 
                quality = True, 
                priority = True, 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else :
            return TranslationOrder(
        )

    def testTranslationOrder(self):
        """Test TranslationOrder"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class KeyCreateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'name': 'str',
        'description': 'str',
        'plural': 'bool',
        'name_plural': 'str',
        'data_type': 'str',
        'tags': 'str',
        'max_characters_allowed': 'int',
        'screenshot': 'file',
        'remove_screenshot': 'bool',
        'unformatted': 'bool',
        'default_translation_content': 'str',
        'xml_space_preserve': 'bool',
        'original_file': 'str',
        'localized_format_string': 'str',
        'localized_format_key': 'str'
    }

    attribute_map = {
        'branch': 'branch',
        'name': 'name',
        'description': 'description',
        'plural': 'plural',
        'name_plural': 'name_plural',
        'data_type': 'data_type',
        'tags': 'tags',
        'max_characters_allowed': 'max_characters_allowed',
        'screenshot': 'screenshot',
        'remove_screenshot': 'remove_screenshot',
        'unformatted': 'unformatted',
        'default_translation_content': 'default_translation_content',
        'xml_space_preserve': 'xml_space_preserve',
        'original_file': 'original_file',
        'localized_format_string': 'localized_format_string',
        'localized_format_key': 'localized_format_key'
    }

    def __init__(self, branch=None, name=None, description=None, plural=None, name_plural=None, data_type=None, tags=None, max_characters_allowed=None, screenshot=None, remove_screenshot=None, unformatted=None, default_translation_content=None, xml_space_preserve=None, original_file=None, localized_format_string=None, localized_format_key=None, local_vars_configuration=None):  # noqa: E501
        """KeyCreateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._name = None
        self._description = None
        self._plural = None
        self._name_plural = None
        self._data_type = None
        self._tags = None
        self._max_characters_allowed = None
        self._screenshot = None
        self._remove_screenshot = None
        self._unformatted = None
        self._default_translation_content = None
        self._xml_space_preserve = None
        self._original_file = None
        self._localized_format_string = None
        self._localized_format_key = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if plural is not None:
            self.plural = plural
        if name_plural is not None:
            self.name_plural = name_plural
        if data_type is not None:
            self.data_type = data_type
        if tags is not None:
            self.tags = tags
        if max_characters_allowed is not None:
            self.max_characters_allowed = max_characters_allowed
        if screenshot is not None:
            self.screenshot = screenshot
        if remove_screenshot is not None:
            self.remove_screenshot = remove_screenshot
        if unformatted is not None:
            self.unformatted = unformatted
        if default_translation_content is not None:
            self.default_translation_content = default_translation_content
        if xml_space_preserve is not None:
            self.xml_space_preserve = xml_space_preserve
        if original_file is not None:
            self.original_file = original_file
        if localized_format_string is not None:
            self.localized_format_string = localized_format_string
        if localized_format_key is not None:
            self.localized_format_key = localized_format_key

    @property
    def branch(self):
        """Gets the branch of this KeyCreateParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this KeyCreateParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def name(self):
        """Gets the name of this KeyCreateParameters.  # noqa: E501

        Key name  # noqa: E501

        :return: The name of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KeyCreateParameters.

        Key name  # noqa: E501

        :param name: The name of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this KeyCreateParameters.  # noqa: E501

        Key description (usually includes contextual information for translators)  # noqa: E501

        :return: The description of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this KeyCreateParameters.

        Key description (usually includes contextual information for translators)  # noqa: E501

        :param description: The description of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def plural(self):
        """Gets the plural of this KeyCreateParameters.  # noqa: E501

        Indicates whether key supports pluralization  # noqa: E501

        :return: The plural of this KeyCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._plural

    @plural.setter
    def plural(self, plural):
        """Sets the plural of this KeyCreateParameters.

        Indicates whether key supports pluralization  # noqa: E501

        :param plural: The plural of this KeyCreateParameters.  # noqa: E501
        :type: bool
        """

        self._plural = plural

    @property
    def name_plural(self):
        """Gets the name_plural of this KeyCreateParameters.  # noqa: E501

        Plural name for the key (used in some file formats, e.g. Gettext)  # noqa: E501

        :return: The name_plural of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._name_plural

    @name_plural.setter
    def name_plural(self, name_plural):
        """Sets the name_plural of this KeyCreateParameters.

        Plural name for the key (used in some file formats, e.g. Gettext)  # noqa: E501

        :param name_plural: The name_plural of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._name_plural = name_plural

    @property
    def data_type(self):
        """Gets the data_type of this KeyCreateParameters.  # noqa: E501

        Type of the key. Can be one of the following: string, number, boolean, array, markdown.  # noqa: E501

        :return: The data_type of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this KeyCreateParameters.

        Type of the key. Can be one of the following: string, number, boolean, array, markdown.  # noqa: E501

        :param data_type: The data_type of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def tags(self):
        """Gets the tags of this KeyCreateParameters.  # noqa: E501

        List of tags separated by comma to be associated with the key.  # noqa: E501

        :return: The tags of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this KeyCreateParameters.

        List of tags separated by comma to be associated with the key.  # noqa: E501

        :param tags: The tags of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._tags = tags

    @property
    def max_characters_allowed(self):
        """Gets the max_characters_allowed of this KeyCreateParameters.  # noqa: E501

        Max. number of characters translations for this key can have.  # noqa: E501

        :return: The max_characters_allowed of this KeyCreateParameters.  # noqa: E501
        :rtype: int
        """
        return self._max_characters_allowed

    @max_characters_allowed.setter
    def max_characters_allowed(self, max_characters_allowed):
        """Sets the max_characters_allowed of this KeyCreateParameters.

        Max. number of characters translations for this key can have.  # noqa: E501

        :param max_characters_allowed: The max_characters_allowed of this KeyCreateParameters.  # noqa: E501
        :type: int
        """

        self._max_characters_allowed = max_characters_allowed

    @property
    def screenshot(self):
        """Gets the screenshot of this KeyCreateParameters.  # noqa: E501

        Screenshot/image for the key. This parameter is deprecated. Please use the Screenshots endpoint instead.  # noqa: E501

        :return: The screenshot of this KeyCreateParameters.  # noqa: E501
        :rtype: file
        """
        return self._screenshot

    @screenshot.setter
    def screenshot(self, screenshot):
        """Sets the screenshot of this KeyCreateParameters.

        Screenshot/image for the key. This parameter is deprecated. Please use the Screenshots endpoint instead.  # noqa: E501

        :param screenshot: The screenshot of this KeyCreateParameters.  # noqa: E501
        :type: file
        """

        self._screenshot = screenshot

    @property
    def remove_screenshot(self):
        """Gets the remove_screenshot of this KeyCreateParameters.  # noqa: E501

        Indicates whether the screenshot will be deleted. This parameter is deprecated. Please use the Screenshots endpoint instead.  # noqa: E501

        :return: The remove_screenshot of this KeyCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._remove_screenshot

    @remove_screenshot.setter
    def remove_screenshot(self, remove_screenshot):
        """Sets the remove_screenshot of this KeyCreateParameters.

        Indicates whether the screenshot will be deleted. This parameter is deprecated. Please use the Screenshots endpoint instead.  # noqa: E501

        :param remove_screenshot: The remove_screenshot of this KeyCreateParameters.  # noqa: E501
        :type: bool
        """

        self._remove_screenshot = remove_screenshot

    @property
    def unformatted(self):
        """Gets the unformatted of this KeyCreateParameters.  # noqa: E501

        Indicates whether the key should be exported as \"unformatted\". Supported by Android XML and other formats.  # noqa: E501

        :return: The unformatted of this KeyCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._unformatted

    @unformatted.setter
    def unformatted(self, unformatted):
        """Sets the unformatted of this KeyCreateParameters.

        Indicates whether the key should be exported as \"unformatted\". Supported by Android XML and other formats.  # noqa: E501

        :param unformatted: The unformatted of this KeyCreateParameters.  # noqa: E501
        :type: bool
        """

        self._unformatted = unformatted

    @property
    def default_translation_content(self):
        """Gets the default_translation_content of this KeyCreateParameters.  # noqa: E501

        Creates a translation in the default locale with the specified content  # noqa: E501

        :return: The default_translation_content of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._default_translation_content

    @default_translation_content.setter
    def default_translation_content(self, default_translation_content):
        """Sets the default_translation_content of this KeyCreateParameters.

        Creates a translation in the default locale with the specified content  # noqa: E501

        :param default_translation_content: The default_translation_content of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._default_translation_content = default_translation_content

    @property
    def xml_space_preserve(self):
        """Gets the xml_space_preserve of this KeyCreateParameters.  # noqa: E501

        Indicates whether the key should be exported with \"xml:space=preserve\". Supported by several XML-based formats.  # noqa: E501

        :return: The xml_space_preserve of this KeyCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._xml_space_preserve

    @xml_space_preserve.setter
    def xml_space_preserve(self, xml_space_preserve):
        """Sets the xml_space_preserve of this KeyCreateParameters.

        Indicates whether the key should be exported with \"xml:space=preserve\". Supported by several XML-based formats.  # noqa: E501

        :param xml_space_preserve: The xml_space_preserve of this KeyCreateParameters.  # noqa: E501
        :type: bool
        """

        self._xml_space_preserve = xml_space_preserve

    @property
    def original_file(self):
        """Gets the original_file of this KeyCreateParameters.  # noqa: E501

        Original file attribute. Used in some formats, e.g. XLIFF.  # noqa: E501

        :return: The original_file of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._original_file

    @original_file.setter
    def original_file(self, original_file):
        """Sets the original_file of this KeyCreateParameters.

        Original file attribute. Used in some formats, e.g. XLIFF.  # noqa: E501

        :param original_file: The original_file of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._original_file = original_file

    @property
    def localized_format_string(self):
        """Gets the localized_format_string of this KeyCreateParameters.  # noqa: E501

        NSStringLocalizedFormatKey attribute. Used in .stringsdict format.  # noqa: E501

        :return: The localized_format_string of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._localized_format_string

    @localized_format_string.setter
    def localized_format_string(self, localized_format_string):
        """Sets the localized_format_string of this KeyCreateParameters.

        NSStringLocalizedFormatKey attribute. Used in .stringsdict format.  # noqa: E501

        :param localized_format_string: The localized_format_string of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._localized_format_string = localized_format_string

    @property
    def localized_format_key(self):
        """Gets the localized_format_key of this KeyCreateParameters.  # noqa: E501

        NSStringLocalizedFormatKey attribute. Used in .stringsdict format.  # noqa: E501

        :return: The localized_format_key of this KeyCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._localized_format_key

    @localized_format_key.setter
    def localized_format_key(self, localized_format_key):
        """Sets the localized_format_key of this KeyCreateParameters.

        NSStringLocalizedFormatKey attribute. Used in .stringsdict format.  # noqa: E501

        :param localized_format_key: The localized_format_key of this KeyCreateParameters.  # noqa: E501
        :type: str
        """

        self._localized_format_key = localized_format_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeyCreateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KeyCreateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class AccountDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'slug': 'str',
        'company': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'company_logo_url': 'str',
        'subscription': 'Subscription'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'slug': 'slug',
        'company': 'company',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'company_logo_url': 'company_logo_url',
        'subscription': 'subscription'
    }

    def __init__(self, id=None, name=None, slug=None, company=None, created_at=None, updated_at=None, company_logo_url=None, subscription=None, local_vars_configuration=None):  # noqa: E501
        """AccountDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._slug = None
        self._company = None
        self._created_at = None
        self._updated_at = None
        self._company_logo_url = None
        self._subscription = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if slug is not None:
            self.slug = slug
        if company is not None:
            self.company = company
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if company_logo_url is not None:
            self.company_logo_url = company_logo_url
        if subscription is not None:
            self.subscription = subscription

    @property
    def id(self):
        """Gets the id of this AccountDetails.  # noqa: E501


        :return: The id of this AccountDetails.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AccountDetails.


        :param id: The id of this AccountDetails.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this AccountDetails.  # noqa: E501


        :return: The name of this AccountDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AccountDetails.


        :param name: The name of this AccountDetails.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def slug(self):
        """Gets the slug of this AccountDetails.  # noqa: E501


        :return: The slug of this AccountDetails.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this AccountDetails.


        :param slug: The slug of this AccountDetails.  # noqa: E501
        :type: str
        """

        self._slug = slug

    @property
    def company(self):
        """Gets the company of this AccountDetails.  # noqa: E501


        :return: The company of this AccountDetails.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this AccountDetails.


        :param company: The company of this AccountDetails.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def created_at(self):
        """Gets the created_at of this AccountDetails.  # noqa: E501


        :return: The created_at of this AccountDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AccountDetails.


        :param created_at: The created_at of this AccountDetails.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this AccountDetails.  # noqa: E501


        :return: The updated_at of this AccountDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this AccountDetails.


        :param updated_at: The updated_at of this AccountDetails.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def company_logo_url(self):
        """Gets the company_logo_url of this AccountDetails.  # noqa: E501


        :return: The company_logo_url of this AccountDetails.  # noqa: E501
        :rtype: str
        """
        return self._company_logo_url

    @company_logo_url.setter
    def company_logo_url(self, company_logo_url):
        """Sets the company_logo_url of this AccountDetails.


        :param company_logo_url: The company_logo_url of this AccountDetails.  # noqa: E501
        :type: str
        """

        self._company_logo_url = company_logo_url

    @property
    def subscription(self):
        """Gets the subscription of this AccountDetails.  # noqa: E501


        :return: The subscription of this AccountDetails.  # noqa: E501
        :rtype: Subscription
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this AccountDetails.


        :param subscription: The subscription of this AccountDetails.  # noqa: E501
        :type: Subscription
        """

        self._subscription = subscription

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.webhook_deliveries_api import WebhookDeliveriesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestWebhookDeliveriesApi(unittest.TestCase):
    """WebhookDeliveriesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.webhook_deliveries_api.WebhookDeliveriesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_webhook_deliveries_list(self):
        """Test case for webhook_deliveries_list

        List webhook deliveries  # noqa: E501
        """
        pass

    def test_webhook_deliveries_redeliver(self):
        """Test case for webhook_deliveries_redeliver

        Redeliver a single webhook delivery  # noqa: E501
        """
        pass

    def test_webhook_deliveries_show(self):
        """Test case for webhook_deliveries_show

        Get a single webhook delivery  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class ProjectUpdateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'name': 'str',
        'main_format': 'str',
        'shares_translation_memory': 'bool',
        'project_image': 'file',
        'remove_project_image': 'bool',
        'workflow': 'str',
        'machine_translation_enabled': 'bool',
        'enable_branching': 'bool',
        'protect_master_branch': 'bool',
        'enable_all_data_type_translation_keys_for_translators': 'bool',
        'enable_icu_message_format': 'bool',
        'zero_plural_form_enabled': 'bool',
        'autotranslate_enabled': 'bool',
        'autotranslate_check_new_translation_keys': 'bool',
        'autotranslate_check_new_uploads': 'bool',
        'autotranslate_check_new_locales': 'bool',
        'autotranslate_mark_as_unverified': 'bool',
        'autotranslate_use_machine_translation': 'bool',
        'autotranslate_use_translation_memory': 'bool',
        'smart_suggest_enabled': 'bool',
        'smart_suggest_use_glossary': 'bool',
        'smart_suggest_use_machine_translation': 'bool'
    }

    attribute_map = {
        'account_id': 'account_id',
        'name': 'name',
        'main_format': 'main_format',
        'shares_translation_memory': 'shares_translation_memory',
        'project_image': 'project_image',
        'remove_project_image': 'remove_project_image',
        'workflow': 'workflow',
        'machine_translation_enabled': 'machine_translation_enabled',
        'enable_branching': 'enable_branching',
        'protect_master_branch': 'protect_master_branch',
        'enable_all_data_type_translation_keys_for_translators': 'enable_all_data_type_translation_keys_for_translators',
        'enable_icu_message_format': 'enable_icu_message_format',
        'zero_plural_form_enabled': 'zero_plural_form_enabled',
        'autotranslate_enabled': 'autotranslate_enabled',
        'autotranslate_check_new_translation_keys': 'autotranslate_check_new_translation_keys',
        'autotranslate_check_new_uploads': 'autotranslate_check_new_uploads',
        'autotranslate_check_new_locales': 'autotranslate_check_new_locales',
        'autotranslate_mark_as_unverified': 'autotranslate_mark_as_unverified',
        'autotranslate_use_machine_translation': 'autotranslate_use_machine_translation',
        'autotranslate_use_translation_memory': 'autotranslate_use_translation_memory',
        'smart_suggest_enabled': 'smart_suggest_enabled',
        'smart_suggest_use_glossary': 'smart_suggest_use_glossary',
        'smart_suggest_use_machine_translation': 'smart_suggest_use_machine_translation'
    }

    def __init__(self, account_id=None, name=None, main_format=None, shares_translation_memory=None, project_image=None, remove_project_image=None, workflow=None, machine_translation_enabled=None, enable_branching=None, protect_master_branch=None, enable_all_data_type_translation_keys_for_translators=None, enable_icu_message_format=None, zero_plural_form_enabled=None, autotranslate_enabled=None, autotranslate_check_new_translation_keys=None, autotranslate_check_new_uploads=None, autotranslate_check_new_locales=None, autotranslate_mark_as_unverified=None, autotranslate_use_machine_translation=None, autotranslate_use_translation_memory=None, smart_suggest_enabled=None, smart_suggest_use_glossary=None, smart_suggest_use_machine_translation=None, local_vars_configuration=None):  # noqa: E501
        """ProjectUpdateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._name = None
        self._main_format = None
        self._shares_translation_memory = None
        self._project_image = None
        self._remove_project_image = None
        self._workflow = None
        self._machine_translation_enabled = None
        self._enable_branching = None
        self._protect_master_branch = None
        self._enable_all_data_type_translation_keys_for_translators = None
        self._enable_icu_message_format = None
        self._zero_plural_form_enabled = None
        self._autotranslate_enabled = None
        self._autotranslate_check_new_translation_keys = None
        self._autotranslate_check_new_uploads = None
        self._autotranslate_check_new_locales = None
        self._autotranslate_mark_as_unverified = None
        self._autotranslate_use_machine_translation = None
        self._autotranslate_use_translation_memory = None
        self._smart_suggest_enabled = None
        self._smart_suggest_use_glossary = None
        self._smart_suggest_use_machine_translation = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if name is not None:
            self.name = name
        if main_format is not None:
            self.main_format = main_format
        if shares_translation_memory is not None:
            self.shares_translation_memory = shares_translation_memory
        if project_image is not None:
            self.project_image = project_image
        if remove_project_image is not None:
            self.remove_project_image = remove_project_image
        if workflow is not None:
            self.workflow = workflow
        if machine_translation_enabled is not None:
            self.machine_translation_enabled = machine_translation_enabled
        if enable_branching is not None:
            self.enable_branching = enable_branching
        if protect_master_branch is not None:
            self.protect_master_branch = protect_master_branch
        if enable_all_data_type_translation_keys_for_translators is not None:
            self.enable_all_data_type_translation_keys_for_translators = enable_all_data_type_translation_keys_for_translators
        if enable_icu_message_format is not None:
            self.enable_icu_message_format = enable_icu_message_format
        if zero_plural_form_enabled is not None:
            self.zero_plural_form_enabled = zero_plural_form_enabled
        if autotranslate_enabled is not None:
            self.autotranslate_enabled = autotranslate_enabled
        if autotranslate_check_new_translation_keys is not None:
            self.autotranslate_check_new_translation_keys = autotranslate_check_new_translation_keys
        if autotranslate_check_new_uploads is not None:
            self.autotranslate_check_new_uploads = autotranslate_check_new_uploads
        if autotranslate_check_new_locales is not None:
            self.autotranslate_check_new_locales = autotranslate_check_new_locales
        if autotranslate_mark_as_unverified is not None:
            self.autotranslate_mark_as_unverified = autotranslate_mark_as_unverified
        if autotranslate_use_machine_translation is not None:
            self.autotranslate_use_machine_translation = autotranslate_use_machine_translation
        if autotranslate_use_translation_memory is not None:
            self.autotranslate_use_translation_memory = autotranslate_use_translation_memory
        if smart_suggest_enabled is not None:
            self.smart_suggest_enabled = smart_suggest_enabled
        if smart_suggest_use_glossary is not None:
            self.smart_suggest_use_glossary = smart_suggest_use_glossary
        if smart_suggest_use_machine_translation is not None:
            self.smart_suggest_use_machine_translation = smart_suggest_use_machine_translation

    @property
    def account_id(self):
        """Gets the account_id of this ProjectUpdateParameters.  # noqa: E501

        Required if the requesting user is a member of multiple accounts. Account ID to specify the actual account the project should be created in.  # noqa: E501

        :return: The account_id of this ProjectUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ProjectUpdateParameters.

        Required if the requesting user is a member of multiple accounts. Account ID to specify the actual account the project should be created in.  # noqa: E501

        :param account_id: The account_id of this ProjectUpdateParameters.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def name(self):
        """Gets the name of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Name of the project  # noqa: E501

        :return: The name of this ProjectUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectUpdateParameters.

        (Optional) Name of the project  # noqa: E501

        :param name: The name of this ProjectUpdateParameters.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def main_format(self):
        """Gets the main_format of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Main file format specified by its API Extension name. Used for locale downloads if no format is specified. For API Extension names of available file formats see <a href=\"https://support.phrase.com/hc/en-us/articles/5784070560412\">Format Guide</a> or our <a href=\"#formats\">Formats API Endpoint</a>.  # noqa: E501

        :return: The main_format of this ProjectUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._main_format

    @main_format.setter
    def main_format(self, main_format):
        """Sets the main_format of this ProjectUpdateParameters.

        (Optional) Main file format specified by its API Extension name. Used for locale downloads if no format is specified. For API Extension names of available file formats see <a href=\"https://support.phrase.com/hc/en-us/articles/5784070560412\">Format Guide</a> or our <a href=\"#formats\">Formats API Endpoint</a>.  # noqa: E501

        :param main_format: The main_format of this ProjectUpdateParameters.  # noqa: E501
        :type: str
        """

        self._main_format = main_format

    @property
    def shares_translation_memory(self):
        """Gets the shares_translation_memory of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Indicates whether the project should share the account's translation memory  # noqa: E501

        :return: The shares_translation_memory of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._shares_translation_memory

    @shares_translation_memory.setter
    def shares_translation_memory(self, shares_translation_memory):
        """Sets the shares_translation_memory of this ProjectUpdateParameters.

        (Optional) Indicates whether the project should share the account's translation memory  # noqa: E501

        :param shares_translation_memory: The shares_translation_memory of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._shares_translation_memory = shares_translation_memory

    @property
    def project_image(self):
        """Gets the project_image of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Image to identify the project  # noqa: E501

        :return: The project_image of this ProjectUpdateParameters.  # noqa: E501
        :rtype: file
        """
        return self._project_image

    @project_image.setter
    def project_image(self, project_image):
        """Sets the project_image of this ProjectUpdateParameters.

        (Optional) Image to identify the project  # noqa: E501

        :param project_image: The project_image of this ProjectUpdateParameters.  # noqa: E501
        :type: file
        """

        self._project_image = project_image

    @property
    def remove_project_image(self):
        """Gets the remove_project_image of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Indicates whether the project image should be deleted.  # noqa: E501

        :return: The remove_project_image of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._remove_project_image

    @remove_project_image.setter
    def remove_project_image(self, remove_project_image):
        """Sets the remove_project_image of this ProjectUpdateParameters.

        (Optional) Indicates whether the project image should be deleted.  # noqa: E501

        :param remove_project_image: The remove_project_image of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._remove_project_image = remove_project_image

    @property
    def workflow(self):
        """Gets the workflow of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Review Workflow. \"simple\" / \"review\". <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\">Read more</a>  # noqa: E501

        :return: The workflow of this ProjectUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """Sets the workflow of this ProjectUpdateParameters.

        (Optional) Review Workflow. \"simple\" / \"review\". <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\">Read more</a>  # noqa: E501

        :param workflow: The workflow of this ProjectUpdateParameters.  # noqa: E501
        :type: str
        """

        self._workflow = workflow

    @property
    def machine_translation_enabled(self):
        """Gets the machine_translation_enabled of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Enable machine translation support in the project. Required for Autopilot and Smart Suggest  # noqa: E501

        :return: The machine_translation_enabled of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._machine_translation_enabled

    @machine_translation_enabled.setter
    def machine_translation_enabled(self, machine_translation_enabled):
        """Sets the machine_translation_enabled of this ProjectUpdateParameters.

        (Optional) Enable machine translation support in the project. Required for Autopilot and Smart Suggest  # noqa: E501

        :param machine_translation_enabled: The machine_translation_enabled of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._machine_translation_enabled = machine_translation_enabled

    @property
    def enable_branching(self):
        """Gets the enable_branching of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Enable branching in the project  # noqa: E501

        :return: The enable_branching of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._enable_branching

    @enable_branching.setter
    def enable_branching(self, enable_branching):
        """Sets the enable_branching of this ProjectUpdateParameters.

        (Optional) Enable branching in the project  # noqa: E501

        :param enable_branching: The enable_branching of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._enable_branching = enable_branching

    @property
    def protect_master_branch(self):
        """Gets the protect_master_branch of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Protect the master branch in project where branching is enabled  # noqa: E501

        :return: The protect_master_branch of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._protect_master_branch

    @protect_master_branch.setter
    def protect_master_branch(self, protect_master_branch):
        """Sets the protect_master_branch of this ProjectUpdateParameters.

        (Optional) Protect the master branch in project where branching is enabled  # noqa: E501

        :param protect_master_branch: The protect_master_branch of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._protect_master_branch = protect_master_branch

    @property
    def enable_all_data_type_translation_keys_for_translators(self):
        """Gets the enable_all_data_type_translation_keys_for_translators of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Otherwise, translators are not allowed to edit translations other than strings  # noqa: E501

        :return: The enable_all_data_type_translation_keys_for_translators of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._enable_all_data_type_translation_keys_for_translators

    @enable_all_data_type_translation_keys_for_translators.setter
    def enable_all_data_type_translation_keys_for_translators(self, enable_all_data_type_translation_keys_for_translators):
        """Sets the enable_all_data_type_translation_keys_for_translators of this ProjectUpdateParameters.

        (Optional) Otherwise, translators are not allowed to edit translations other than strings  # noqa: E501

        :param enable_all_data_type_translation_keys_for_translators: The enable_all_data_type_translation_keys_for_translators of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._enable_all_data_type_translation_keys_for_translators = enable_all_data_type_translation_keys_for_translators

    @property
    def enable_icu_message_format(self):
        """Gets the enable_icu_message_format of this ProjectUpdateParameters.  # noqa: E501

        (Optional) We can validate and highlight your ICU messages. <a href=\"https://support.phrase.com/hc/en-us/articles/5822319545116\">Read more</a>  # noqa: E501

        :return: The enable_icu_message_format of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._enable_icu_message_format

    @enable_icu_message_format.setter
    def enable_icu_message_format(self, enable_icu_message_format):
        """Sets the enable_icu_message_format of this ProjectUpdateParameters.

        (Optional) We can validate and highlight your ICU messages. <a href=\"https://support.phrase.com/hc/en-us/articles/5822319545116\">Read more</a>  # noqa: E501

        :param enable_icu_message_format: The enable_icu_message_format of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._enable_icu_message_format = enable_icu_message_format

    @property
    def zero_plural_form_enabled(self):
        """Gets the zero_plural_form_enabled of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Displays the input fields for the 'ZERO' plural form for every key as well although only some languages require the 'ZERO' explicitly.  # noqa: E501

        :return: The zero_plural_form_enabled of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._zero_plural_form_enabled

    @zero_plural_form_enabled.setter
    def zero_plural_form_enabled(self, zero_plural_form_enabled):
        """Sets the zero_plural_form_enabled of this ProjectUpdateParameters.

        (Optional) Displays the input fields for the 'ZERO' plural form for every key as well although only some languages require the 'ZERO' explicitly.  # noqa: E501

        :param zero_plural_form_enabled: The zero_plural_form_enabled of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._zero_plural_form_enabled = zero_plural_form_enabled

    @property
    def autotranslate_enabled(self):
        """Gets the autotranslate_enabled of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Autopilot, requires machine_translation_enabled. <a href=\"https://support.phrase.com/hc/en-us/articles/5822187934364\">Read more</a>  # noqa: E501

        :return: The autotranslate_enabled of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate_enabled

    @autotranslate_enabled.setter
    def autotranslate_enabled(self, autotranslate_enabled):
        """Sets the autotranslate_enabled of this ProjectUpdateParameters.

        (Optional) Autopilot, requires machine_translation_enabled. <a href=\"https://support.phrase.com/hc/en-us/articles/5822187934364\">Read more</a>  # noqa: E501

        :param autotranslate_enabled: The autotranslate_enabled of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate_enabled = autotranslate_enabled

    @property
    def autotranslate_check_new_translation_keys(self):
        """Gets the autotranslate_check_new_translation_keys of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :return: The autotranslate_check_new_translation_keys of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate_check_new_translation_keys

    @autotranslate_check_new_translation_keys.setter
    def autotranslate_check_new_translation_keys(self, autotranslate_check_new_translation_keys):
        """Sets the autotranslate_check_new_translation_keys of this ProjectUpdateParameters.

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :param autotranslate_check_new_translation_keys: The autotranslate_check_new_translation_keys of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate_check_new_translation_keys = autotranslate_check_new_translation_keys

    @property
    def autotranslate_check_new_uploads(self):
        """Gets the autotranslate_check_new_uploads of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :return: The autotranslate_check_new_uploads of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate_check_new_uploads

    @autotranslate_check_new_uploads.setter
    def autotranslate_check_new_uploads(self, autotranslate_check_new_uploads):
        """Sets the autotranslate_check_new_uploads of this ProjectUpdateParameters.

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :param autotranslate_check_new_uploads: The autotranslate_check_new_uploads of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate_check_new_uploads = autotranslate_check_new_uploads

    @property
    def autotranslate_check_new_locales(self):
        """Gets the autotranslate_check_new_locales of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :return: The autotranslate_check_new_locales of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate_check_new_locales

    @autotranslate_check_new_locales.setter
    def autotranslate_check_new_locales(self, autotranslate_check_new_locales):
        """Sets the autotranslate_check_new_locales of this ProjectUpdateParameters.

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :param autotranslate_check_new_locales: The autotranslate_check_new_locales of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate_check_new_locales = autotranslate_check_new_locales

    @property
    def autotranslate_mark_as_unverified(self):
        """Gets the autotranslate_mark_as_unverified of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :return: The autotranslate_mark_as_unverified of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate_mark_as_unverified

    @autotranslate_mark_as_unverified.setter
    def autotranslate_mark_as_unverified(self, autotranslate_mark_as_unverified):
        """Sets the autotranslate_mark_as_unverified of this ProjectUpdateParameters.

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :param autotranslate_mark_as_unverified: The autotranslate_mark_as_unverified of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate_mark_as_unverified = autotranslate_mark_as_unverified

    @property
    def autotranslate_use_machine_translation(self):
        """Gets the autotranslate_use_machine_translation of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :return: The autotranslate_use_machine_translation of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate_use_machine_translation

    @autotranslate_use_machine_translation.setter
    def autotranslate_use_machine_translation(self, autotranslate_use_machine_translation):
        """Sets the autotranslate_use_machine_translation of this ProjectUpdateParameters.

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :param autotranslate_use_machine_translation: The autotranslate_use_machine_translation of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate_use_machine_translation = autotranslate_use_machine_translation

    @property
    def autotranslate_use_translation_memory(self):
        """Gets the autotranslate_use_translation_memory of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :return: The autotranslate_use_translation_memory of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate_use_translation_memory

    @autotranslate_use_translation_memory.setter
    def autotranslate_use_translation_memory(self, autotranslate_use_translation_memory):
        """Sets the autotranslate_use_translation_memory of this ProjectUpdateParameters.

        (Optional) Requires autotranslate_enabled to be true  # noqa: E501

        :param autotranslate_use_translation_memory: The autotranslate_use_translation_memory of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate_use_translation_memory = autotranslate_use_translation_memory

    @property
    def smart_suggest_enabled(self):
        """Gets the smart_suggest_enabled of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Smart Suggest, requires machine_translation_enabled  # noqa: E501

        :return: The smart_suggest_enabled of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._smart_suggest_enabled

    @smart_suggest_enabled.setter
    def smart_suggest_enabled(self, smart_suggest_enabled):
        """Sets the smart_suggest_enabled of this ProjectUpdateParameters.

        (Optional) Smart Suggest, requires machine_translation_enabled  # noqa: E501

        :param smart_suggest_enabled: The smart_suggest_enabled of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._smart_suggest_enabled = smart_suggest_enabled

    @property
    def smart_suggest_use_glossary(self):
        """Gets the smart_suggest_use_glossary of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Requires smart_suggest_enabled to be true  # noqa: E501

        :return: The smart_suggest_use_glossary of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._smart_suggest_use_glossary

    @smart_suggest_use_glossary.setter
    def smart_suggest_use_glossary(self, smart_suggest_use_glossary):
        """Sets the smart_suggest_use_glossary of this ProjectUpdateParameters.

        (Optional) Requires smart_suggest_enabled to be true  # noqa: E501

        :param smart_suggest_use_glossary: The smart_suggest_use_glossary of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._smart_suggest_use_glossary = smart_suggest_use_glossary

    @property
    def smart_suggest_use_machine_translation(self):
        """Gets the smart_suggest_use_machine_translation of this ProjectUpdateParameters.  # noqa: E501

        (Optional) Requires smart_suggest_enabled to be true  # noqa: E501

        :return: The smart_suggest_use_machine_translation of this ProjectUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._smart_suggest_use_machine_translation

    @smart_suggest_use_machine_translation.setter
    def smart_suggest_use_machine_translation(self, smart_suggest_use_machine_translation):
        """Sets the smart_suggest_use_machine_translation of this ProjectUpdateParameters.

        (Optional) Requires smart_suggest_enabled to be true  # noqa: E501

        :param smart_suggest_use_machine_translation: The smart_suggest_use_machine_translation of this ProjectUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._smart_suggest_use_machine_translation = smart_suggest_use_machine_translation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectUpdateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectUpdateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class IcuSkeletonParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content': 'str',
        'locale_codes': 'list[str]',
        'keep_content': 'bool',
        'zero_form_enabled': 'bool'
    }

    attribute_map = {
        'content': 'content',
        'locale_codes': 'locale_codes',
        'keep_content': 'keep_content',
        'zero_form_enabled': 'zero_form_enabled'
    }

    def __init__(self, content=None, locale_codes=None, keep_content=None, zero_form_enabled=None, local_vars_configuration=None):  # noqa: E501
        """IcuSkeletonParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content = None
        self._locale_codes = None
        self._keep_content = None
        self._zero_form_enabled = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if locale_codes is not None:
            self.locale_codes = locale_codes
        if keep_content is not None:
            self.keep_content = keep_content
        if zero_form_enabled is not None:
            self.zero_form_enabled = zero_form_enabled

    @property
    def content(self):
        """Gets the content of this IcuSkeletonParameters.  # noqa: E501

        Source content  # noqa: E501

        :return: The content of this IcuSkeletonParameters.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this IcuSkeletonParameters.

        Source content  # noqa: E501

        :param content: The content of this IcuSkeletonParameters.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def locale_codes(self):
        """Gets the locale_codes of this IcuSkeletonParameters.  # noqa: E501

        Locale codes  # noqa: E501

        :return: The locale_codes of this IcuSkeletonParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._locale_codes

    @locale_codes.setter
    def locale_codes(self, locale_codes):
        """Sets the locale_codes of this IcuSkeletonParameters.

        Locale codes  # noqa: E501

        :param locale_codes: The locale_codes of this IcuSkeletonParameters.  # noqa: E501
        :type: list[str]
        """

        self._locale_codes = locale_codes

    @property
    def keep_content(self):
        """Gets the keep_content of this IcuSkeletonParameters.  # noqa: E501

        Keep the content and add missing plural forms for each locale  # noqa: E501

        :return: The keep_content of this IcuSkeletonParameters.  # noqa: E501
        :rtype: bool
        """
        return self._keep_content

    @keep_content.setter
    def keep_content(self, keep_content):
        """Sets the keep_content of this IcuSkeletonParameters.

        Keep the content and add missing plural forms for each locale  # noqa: E501

        :param keep_content: The keep_content of this IcuSkeletonParameters.  # noqa: E501
        :type: bool
        """

        self._keep_content = keep_content

    @property
    def zero_form_enabled(self):
        """Gets the zero_form_enabled of this IcuSkeletonParameters.  # noqa: E501

        Indicates whether the zero form should be included or excluded in the returned skeletons  # noqa: E501

        :return: The zero_form_enabled of this IcuSkeletonParameters.  # noqa: E501
        :rtype: bool
        """
        return self._zero_form_enabled

    @zero_form_enabled.setter
    def zero_form_enabled(self, zero_form_enabled):
        """Sets the zero_form_enabled of this IcuSkeletonParameters.

        Indicates whether the zero form should be included or excluded in the returned skeletons  # noqa: E501

        :param zero_form_enabled: The zero_form_enabled of this IcuSkeletonParameters.  # noqa: E501
        :type: bool
        """

        self._zero_form_enabled = zero_form_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IcuSkeletonParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IcuSkeletonParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class Locale(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'code': 'str',
        'default': 'bool',
        'main': 'bool',
        'rtl': 'bool',
        'plural_forms': 'list[str]',
        'source_locale': 'LocalePreview',
        'fallback_locale': 'LocalePreview',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'code': 'code',
        'default': 'default',
        'main': 'main',
        'rtl': 'rtl',
        'plural_forms': 'plural_forms',
        'source_locale': 'source_locale',
        'fallback_locale': 'fallback_locale',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, name=None, code=None, default=None, main=None, rtl=None, plural_forms=None, source_locale=None, fallback_locale=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """Locale - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._code = None
        self._default = None
        self._main = None
        self._rtl = None
        self._plural_forms = None
        self._source_locale = None
        self._fallback_locale = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if code is not None:
            self.code = code
        if default is not None:
            self.default = default
        if main is not None:
            self.main = main
        if rtl is not None:
            self.rtl = rtl
        if plural_forms is not None:
            self.plural_forms = plural_forms
        if source_locale is not None:
            self.source_locale = source_locale
        if fallback_locale is not None:
            self.fallback_locale = fallback_locale
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this Locale.  # noqa: E501


        :return: The id of this Locale.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Locale.


        :param id: The id of this Locale.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Locale.  # noqa: E501


        :return: The name of this Locale.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Locale.


        :param name: The name of this Locale.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def code(self):
        """Gets the code of this Locale.  # noqa: E501


        :return: The code of this Locale.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Locale.


        :param code: The code of this Locale.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def default(self):
        """Gets the default of this Locale.  # noqa: E501


        :return: The default of this Locale.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this Locale.


        :param default: The default of this Locale.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def main(self):
        """Gets the main of this Locale.  # noqa: E501


        :return: The main of this Locale.  # noqa: E501
        :rtype: bool
        """
        return self._main

    @main.setter
    def main(self, main):
        """Sets the main of this Locale.


        :param main: The main of this Locale.  # noqa: E501
        :type: bool
        """

        self._main = main

    @property
    def rtl(self):
        """Gets the rtl of this Locale.  # noqa: E501


        :return: The rtl of this Locale.  # noqa: E501
        :rtype: bool
        """
        return self._rtl

    @rtl.setter
    def rtl(self, rtl):
        """Sets the rtl of this Locale.


        :param rtl: The rtl of this Locale.  # noqa: E501
        :type: bool
        """

        self._rtl = rtl

    @property
    def plural_forms(self):
        """Gets the plural_forms of this Locale.  # noqa: E501


        :return: The plural_forms of this Locale.  # noqa: E501
        :rtype: list[str]
        """
        return self._plural_forms

    @plural_forms.setter
    def plural_forms(self, plural_forms):
        """Sets the plural_forms of this Locale.


        :param plural_forms: The plural_forms of this Locale.  # noqa: E501
        :type: list[str]
        """

        self._plural_forms = plural_forms

    @property
    def source_locale(self):
        """Gets the source_locale of this Locale.  # noqa: E501


        :return: The source_locale of this Locale.  # noqa: E501
        :rtype: LocalePreview
        """
        return self._source_locale

    @source_locale.setter
    def source_locale(self, source_locale):
        """Sets the source_locale of this Locale.


        :param source_locale: The source_locale of this Locale.  # noqa: E501
        :type: LocalePreview
        """

        self._source_locale = source_locale

    @property
    def fallback_locale(self):
        """Gets the fallback_locale of this Locale.  # noqa: E501


        :return: The fallback_locale of this Locale.  # noqa: E501
        :rtype: LocalePreview
        """
        return self._fallback_locale

    @fallback_locale.setter
    def fallback_locale(self, fallback_locale):
        """Sets the fallback_locale of this Locale.


        :param fallback_locale: The fallback_locale of this Locale.  # noqa: E501
        :type: LocalePreview
        """

        self._fallback_locale = fallback_locale

    @property
    def created_at(self):
        """Gets the created_at of this Locale.  # noqa: E501


        :return: The created_at of this Locale.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Locale.


        :param created_at: The created_at of this Locale.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Locale.  # noqa: E501


        :return: The updated_at of this Locale.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Locale.


        :param updated_at: The updated_at of this Locale.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Locale):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Locale):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class SearchInAccountParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'query': 'str',
        'locale_code': 'str',
        'page': 'int',
        'per_page': 'int'
    }

    attribute_map = {
        'query': 'query',
        'locale_code': 'locale_code',
        'page': 'page',
        'per_page': 'per_page'
    }

    def __init__(self, query=None, locale_code=None, page=None, per_page=None, local_vars_configuration=None):  # noqa: E501
        """SearchInAccountParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._query = None
        self._locale_code = None
        self._page = None
        self._per_page = None
        self.discriminator = None

        if query is not None:
            self.query = query
        if locale_code is not None:
            self.locale_code = locale_code
        if page is not None:
            self.page = page
        if per_page is not None:
            self.per_page = per_page

    @property
    def query(self):
        """Gets the query of this SearchInAccountParameters.  # noqa: E501

        Search query  # noqa: E501

        :return: The query of this SearchInAccountParameters.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this SearchInAccountParameters.

        Search query  # noqa: E501

        :param query: The query of this SearchInAccountParameters.  # noqa: E501
        :type: str
        """

        self._query = query

    @property
    def locale_code(self):
        """Gets the locale_code of this SearchInAccountParameters.  # noqa: E501

        Locale code  # noqa: E501

        :return: The locale_code of this SearchInAccountParameters.  # noqa: E501
        :rtype: str
        """
        return self._locale_code

    @locale_code.setter
    def locale_code(self, locale_code):
        """Sets the locale_code of this SearchInAccountParameters.

        Locale code  # noqa: E501

        :param locale_code: The locale_code of this SearchInAccountParameters.  # noqa: E501
        :type: str
        """

        self._locale_code = locale_code

    @property
    def page(self):
        """Gets the page of this SearchInAccountParameters.  # noqa: E501

        Page  # noqa: E501

        :return: The page of this SearchInAccountParameters.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this SearchInAccountParameters.

        Page  # noqa: E501

        :param page: The page of this SearchInAccountParameters.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def per_page(self):
        """Gets the per_page of this SearchInAccountParameters.  # noqa: E501

        Number of results per page  # noqa: E501

        :return: The per_page of this SearchInAccountParameters.  # noqa: E501
        :rtype: int
        """
        return self._per_page

    @per_page.setter
    def per_page(self, per_page):
        """Sets the per_page of this SearchInAccountParameters.

        Number of results per page  # noqa: E501

        :param per_page: The per_page of this SearchInAccountParameters.  # noqa: E501
        :type: int
        """

        self._per_page = per_page

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchInAccountParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchInAccountParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class TranslationKeyDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'name_hash': 'str',
        'plural': 'bool',
        'tags': 'list[str]',
        'data_type': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'name_plural': 'str',
        'comments_count': 'int',
        'max_characters_allowed': 'int',
        'screenshot_url': 'str',
        'unformatted': 'bool',
        'xml_space_preserve': 'bool',
        'original_file': 'str',
        'format_value_type': 'str',
        'creator': 'UserPreview'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'name_hash': 'name_hash',
        'plural': 'plural',
        'tags': 'tags',
        'data_type': 'data_type',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'name_plural': 'name_plural',
        'comments_count': 'comments_count',
        'max_characters_allowed': 'max_characters_allowed',
        'screenshot_url': 'screenshot_url',
        'unformatted': 'unformatted',
        'xml_space_preserve': 'xml_space_preserve',
        'original_file': 'original_file',
        'format_value_type': 'format_value_type',
        'creator': 'creator'
    }

    def __init__(self, id=None, name=None, description=None, name_hash=None, plural=None, tags=None, data_type=None, created_at=None, updated_at=None, name_plural=None, comments_count=None, max_characters_allowed=None, screenshot_url=None, unformatted=None, xml_space_preserve=None, original_file=None, format_value_type=None, creator=None, local_vars_configuration=None):  # noqa: E501
        """TranslationKeyDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._name_hash = None
        self._plural = None
        self._tags = None
        self._data_type = None
        self._created_at = None
        self._updated_at = None
        self._name_plural = None
        self._comments_count = None
        self._max_characters_allowed = None
        self._screenshot_url = None
        self._unformatted = None
        self._xml_space_preserve = None
        self._original_file = None
        self._format_value_type = None
        self._creator = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if name_hash is not None:
            self.name_hash = name_hash
        if plural is not None:
            self.plural = plural
        if tags is not None:
            self.tags = tags
        if data_type is not None:
            self.data_type = data_type
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if name_plural is not None:
            self.name_plural = name_plural
        if comments_count is not None:
            self.comments_count = comments_count
        if max_characters_allowed is not None:
            self.max_characters_allowed = max_characters_allowed
        if screenshot_url is not None:
            self.screenshot_url = screenshot_url
        if unformatted is not None:
            self.unformatted = unformatted
        if xml_space_preserve is not None:
            self.xml_space_preserve = xml_space_preserve
        if original_file is not None:
            self.original_file = original_file
        if format_value_type is not None:
            self.format_value_type = format_value_type
        if creator is not None:
            self.creator = creator

    @property
    def id(self):
        """Gets the id of this TranslationKeyDetails.  # noqa: E501


        :return: The id of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TranslationKeyDetails.


        :param id: The id of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this TranslationKeyDetails.  # noqa: E501


        :return: The name of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TranslationKeyDetails.


        :param name: The name of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this TranslationKeyDetails.  # noqa: E501


        :return: The description of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TranslationKeyDetails.


        :param description: The description of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name_hash(self):
        """Gets the name_hash of this TranslationKeyDetails.  # noqa: E501


        :return: The name_hash of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._name_hash

    @name_hash.setter
    def name_hash(self, name_hash):
        """Sets the name_hash of this TranslationKeyDetails.


        :param name_hash: The name_hash of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._name_hash = name_hash

    @property
    def plural(self):
        """Gets the plural of this TranslationKeyDetails.  # noqa: E501


        :return: The plural of this TranslationKeyDetails.  # noqa: E501
        :rtype: bool
        """
        return self._plural

    @plural.setter
    def plural(self, plural):
        """Sets the plural of this TranslationKeyDetails.


        :param plural: The plural of this TranslationKeyDetails.  # noqa: E501
        :type: bool
        """

        self._plural = plural

    @property
    def tags(self):
        """Gets the tags of this TranslationKeyDetails.  # noqa: E501


        :return: The tags of this TranslationKeyDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this TranslationKeyDetails.


        :param tags: The tags of this TranslationKeyDetails.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def data_type(self):
        """Gets the data_type of this TranslationKeyDetails.  # noqa: E501


        :return: The data_type of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this TranslationKeyDetails.


        :param data_type: The data_type of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def created_at(self):
        """Gets the created_at of this TranslationKeyDetails.  # noqa: E501


        :return: The created_at of this TranslationKeyDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TranslationKeyDetails.


        :param created_at: The created_at of this TranslationKeyDetails.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this TranslationKeyDetails.  # noqa: E501


        :return: The updated_at of this TranslationKeyDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this TranslationKeyDetails.


        :param updated_at: The updated_at of this TranslationKeyDetails.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def name_plural(self):
        """Gets the name_plural of this TranslationKeyDetails.  # noqa: E501


        :return: The name_plural of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._name_plural

    @name_plural.setter
    def name_plural(self, name_plural):
        """Sets the name_plural of this TranslationKeyDetails.


        :param name_plural: The name_plural of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._name_plural = name_plural

    @property
    def comments_count(self):
        """Gets the comments_count of this TranslationKeyDetails.  # noqa: E501


        :return: The comments_count of this TranslationKeyDetails.  # noqa: E501
        :rtype: int
        """
        return self._comments_count

    @comments_count.setter
    def comments_count(self, comments_count):
        """Sets the comments_count of this TranslationKeyDetails.


        :param comments_count: The comments_count of this TranslationKeyDetails.  # noqa: E501
        :type: int
        """

        self._comments_count = comments_count

    @property
    def max_characters_allowed(self):
        """Gets the max_characters_allowed of this TranslationKeyDetails.  # noqa: E501


        :return: The max_characters_allowed of this TranslationKeyDetails.  # noqa: E501
        :rtype: int
        """
        return self._max_characters_allowed

    @max_characters_allowed.setter
    def max_characters_allowed(self, max_characters_allowed):
        """Sets the max_characters_allowed of this TranslationKeyDetails.


        :param max_characters_allowed: The max_characters_allowed of this TranslationKeyDetails.  # noqa: E501
        :type: int
        """

        self._max_characters_allowed = max_characters_allowed

    @property
    def screenshot_url(self):
        """Gets the screenshot_url of this TranslationKeyDetails.  # noqa: E501


        :return: The screenshot_url of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._screenshot_url

    @screenshot_url.setter
    def screenshot_url(self, screenshot_url):
        """Sets the screenshot_url of this TranslationKeyDetails.


        :param screenshot_url: The screenshot_url of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._screenshot_url = screenshot_url

    @property
    def unformatted(self):
        """Gets the unformatted of this TranslationKeyDetails.  # noqa: E501


        :return: The unformatted of this TranslationKeyDetails.  # noqa: E501
        :rtype: bool
        """
        return self._unformatted

    @unformatted.setter
    def unformatted(self, unformatted):
        """Sets the unformatted of this TranslationKeyDetails.


        :param unformatted: The unformatted of this TranslationKeyDetails.  # noqa: E501
        :type: bool
        """

        self._unformatted = unformatted

    @property
    def xml_space_preserve(self):
        """Gets the xml_space_preserve of this TranslationKeyDetails.  # noqa: E501


        :return: The xml_space_preserve of this TranslationKeyDetails.  # noqa: E501
        :rtype: bool
        """
        return self._xml_space_preserve

    @xml_space_preserve.setter
    def xml_space_preserve(self, xml_space_preserve):
        """Sets the xml_space_preserve of this TranslationKeyDetails.


        :param xml_space_preserve: The xml_space_preserve of this TranslationKeyDetails.  # noqa: E501
        :type: bool
        """

        self._xml_space_preserve = xml_space_preserve

    @property
    def original_file(self):
        """Gets the original_file of this TranslationKeyDetails.  # noqa: E501


        :return: The original_file of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._original_file

    @original_file.setter
    def original_file(self, original_file):
        """Sets the original_file of this TranslationKeyDetails.


        :param original_file: The original_file of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._original_file = original_file

    @property
    def format_value_type(self):
        """Gets the format_value_type of this TranslationKeyDetails.  # noqa: E501


        :return: The format_value_type of this TranslationKeyDetails.  # noqa: E501
        :rtype: str
        """
        return self._format_value_type

    @format_value_type.setter
    def format_value_type(self, format_value_type):
        """Sets the format_value_type of this TranslationKeyDetails.


        :param format_value_type: The format_value_type of this TranslationKeyDetails.  # noqa: E501
        :type: str
        """

        self._format_value_type = format_value_type

    @property
    def creator(self):
        """Gets the creator of this TranslationKeyDetails.  # noqa: E501


        :return: The creator of this TranslationKeyDetails.  # noqa: E501
        :rtype: UserPreview
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this TranslationKeyDetails.


        :param creator: The creator of this TranslationKeyDetails.  # noqa: E501
        :type: UserPreview
        """

        self._creator = creator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranslationKeyDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TranslationKeyDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.style_guides_api import StyleGuidesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestStyleGuidesApi(unittest.TestCase):
    """StyleGuidesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.style_guides_api.StyleGuidesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_styleguide_create(self):
        """Test case for styleguide_create

        Create a style guide  # noqa: E501
        """
        pass

    def test_styleguide_delete(self):
        """Test case for styleguide_delete

        Delete a style guide  # noqa: E501
        """
        pass

    def test_styleguide_show(self):
        """Test case for styleguide_show

        Get a single style guide  # noqa: E501
        """
        pass

    def test_styleguide_update(self):
        """Test case for styleguide_update

        Update a style guide  # noqa: E501
        """
        pass

    def test_styleguides_list(self):
        """Test case for styleguides_list

        List style guides  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.glossary_term_translations_api import GlossaryTermTranslationsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestGlossaryTermTranslationsApi(unittest.TestCase):
    """GlossaryTermTranslationsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.glossary_term_translations_api.GlossaryTermTranslationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_glossary_term_translation_create(self):
        """Test case for glossary_term_translation_create

        Create a translation for a term  # noqa: E501
        """
        pass

    def test_glossary_term_translation_delete(self):
        """Test case for glossary_term_translation_delete

        Delete a translation for a term  # noqa: E501
        """
        pass

    def test_glossary_term_translation_update(self):
        """Test case for glossary_term_translation_update

        Update a translation for a term  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.notification import Notification  # noqa: E501
from phrase_api.rest import ApiException

class TestNotification(unittest.TestCase):
    """Notification unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Notification
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.notification.Notification()  # noqa: E501
        if include_optional :
            return Notification(
                id = '0', 
                event_name = '0', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                delivered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                seen_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                data = None, 
                resource = None, 
                locale = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"de","code":"de-DE","default":true,"main":false,"rtl":false,"plural_forms":["zero","one","other"],"source_locale":{"id":"abcd1234cdef1234abcd1234cdef1234","name":"en","code":"en-GB"},"fallback_locale":{"id":"abcd1234cdef1234abcd1234cdef1234","name":"en","code":"en-GB"},"created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}, 
                user = phrase_api.models.user_preview.user_preview(
                    id = '0', 
                    username = '0', 
                    name = '0', 
                    gravatar_uid = '0', ), 
                project = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"My Android Project","slug":"android_project","main_format":"xml","project_image_url":"http://assets.example.com/project.png","account":"account","space":"space","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}, 
                account = {"id":"abcd1234","name":"Company Account","slug":"company_account","company":"My Awesome Company","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z","company_logo_url":"http://assets.example.com/company_logo.png"}, 
                group = {"id":"abcd1234cdef1234abcd1234cdef1234","event_name":"keys:create","created_at":"2015-01-28T09:52:53Z","updated_at":"2015-01-28T09:52:53Z"}
            )
        else :
            return Notification(
        )

    def testNotification(self):
        """Test Notification"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
